## This app is currently hosted online at pettigrew.shinyapps.io/dags

require(igraph)

source("generate dataset function.R")
source("estimate effect function.R")
source("graphing functions.R")


shinyServer(
  function(input, output) {
    datas <- eventReactive(input$sim.data, {
      d <- list()
      for(ii in 1:input$n.datasets){
        d[[ii]] <- generate.dataset(obs = input$obs,
                                    x2.to.x1 = input$x2.x1.link,
                                    d.to.y.fx = as.numeric(input$treat.fx))
      }
      
      list(ate = as.numeric(input$treat.fx), 
           data = d)
    })
    
    
    reg.res <- eventReactive(input$estimate, {
      h <- datas()
      list(ate = h$ate,
           res = lapply(h$d, est.fx,
                        x1.control = input$X1,
                        x2.control = input$X2,
                        x3.control = input$X3,
                        x4.control = input$X4))
    })
    
    
    output$graph <- renderPlot({
      graph.treatment(list.of.res = reg.res(),
                      n.datasets = input$n.datasets)
    })
    
    output$dag <- renderPlot({
      graph.dag(x2.to.x1 = input$x2.x1.link)
    })
    
    output$stats <- renderText({
      stats = summary.stats(list.of.res = reg.res())
      paste0("The mean squared error is ", 
             round(stats[1],4),
             ".  ",
             round(stats[2], 1),
             "% of datasets captured the true ATE")
    })
    
  }
  )